import { Span } from '@opentelemetry/api';
import type { FastifyReply } from 'fastify';
import { spanRequestSymbol } from './constants';
export declare type HandlerOriginal = (() => Promise<unknown>) & (() => void);
export declare type PluginFastifyReply = FastifyReply & {
    [spanRequestSymbol]?: Span[];
};
//# sourceMappingURL=internal-types.d.ts.map